@@ -1,4 +1,13 @@
-# Function slightly modified from polygon sample code to format the date string 
+# Import required libraries
+import datetime
+import time
+from polygon import RESTClient # Make sure to have the latest API client of Polygon
+from sqlalchemy import create_engine
+from sqlalchemy import text
+from math import sqrt
+from math import floor
+
+# Function slightly modified from polygon sample code to format the date string
 def ts_to_datetime(ts) -> str:
     return datetime.datetime.fromtimestamp(ts / 1000.0).strftime('%Y-%m-%d %H:%M:%S')
 
